@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2006 Mekensleep
 #
 # Mekensleep
@@ -9,7 +9,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -150,8 +150,11 @@ class FakeCurrencyClient:
         self.check_note_result = True
         self.commit_result = True
         
+    def message(self, string):
+        print "FakeCurrencyClient: " + string
+        
     def breakNote(self, (url, serial, name, value), *values):
-        if Verbose: print "breakNote vaues %s" % str(values)
+        if Verbose: self.message("breakNote vaues %s" % str(values))
         if values: 
             values = map(int, values)
             values.sort()
@@ -181,7 +184,7 @@ class FakeCurrencyClient:
         return d
 
     def mergeNotes(self, *notes):
-        if Verbose: print "mergeNotes"
+        if Verbose: self.message("mergeNotes")
         self.serial += 1
         result = list(notes[0])
         result[1] = self.serial
@@ -194,7 +197,7 @@ class FakeCurrencyClient:
     meltNotes = mergeNotes
 
     def changeNote(self, note):
-        if Verbose: print "changeNote"
+        if Verbose: self.message("changeNote")
         self.serial += 1
         result = note.copy()
         result[1] = self.serial
@@ -204,20 +207,20 @@ class FakeCurrencyClient:
         return d
 
     def _buildNote(self, url, value):
-        if Verbose: print "_buildNote"
+        if Verbose: self.message("_buildNote")
         self.serial += 1
         name = "%040d" % self.serial
         return ( url, self.serial, name, value )
 
     def getNote(self, url, value):
-        if Verbose: print "getNote"
+        if Verbose: self.message("getNote")
         note = self._buildNote(url, value)
         d = defer.Deferred()
         reactor.callLater(0, lambda: d.callback(note))
         return d
 
     def checkNote(self, note):
-        if Verbose: print "checkNote"
+        if Verbose: self.message("checkNote")
         if self.check_note_result:
             result = note
         else:
@@ -227,7 +230,7 @@ class FakeCurrencyClient:
         return d
 
     def commit(self, url, transaction_id):
-        if Verbose: print "commit"
+        if Verbose: self.message("commit")
         if self.commit_result:
             result = "OK"
         else:
