@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -9,7 +9,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -235,7 +235,7 @@ class Packet:
         return "type = %s(%d)" % ( PacketNames[self.type], self.type )
 
     def infoStr(self):
-        strings = []
+        strings = [ PacketNames[self.type] + " " ]
         for (field, default, format) in self.info:
             strings.append(field + " = " + str(self.__dict__[field]))
         return " ".join(strings)
@@ -250,7 +250,7 @@ class Packet:
     def infoDeclare(dictionary, type, base_type, name, index):
         dictionary['PacketNames'][index] = name
         dictionary['PacketFactory'][index] = type
-        dictionary[name] = index
+        dictionary['PACKET_' + name] = index
         type.type = index
         type.__init__ = Packet.infoInit
         type.pack = Packet.infoPack
