@@ -1,7 +1,8 @@
 #
 # -*- coding: iso-8859-1 -*-
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2008 Bradley M. Kuhn <bkuhn@ebb.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -11,7 +12,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -55,16 +56,17 @@ class PokerAvatar:
         self.noqueuePackets()
 
     def __str__(self):
-        print "PokerAvatar serial = %s, name = %s" % ( self.getSerial(), self.getName() )
+        return "PokerAvatar serial = %s, name = %s" % ( self.getSerial(), self.getName() )
 
     def setExplain(self, what):
-        if self.tables:
-            self.error("setExplain must be called when not connected to any table")
-            return False
-        
         if what:
-            self.explain = PokerExplain(dirs = self.service.dirs,
-                                        verbose = self.service.verbose)
+            if self.explain == None:
+                if self.tables:
+                    self.error("setExplain must be called when not connected to any table")
+                    return False
+
+                self.explain = PokerExplain(dirs = self.service.dirs,
+                                            verbose = self.service.verbose)
         else:
             self.explain = None
         return True
@@ -76,10 +78,10 @@ class PokerAvatar:
 #       self.message("instance deleted")
 
     def error(self, string):
-        self.message("ERROR " + string)
+        self.message("ERROR " + str(string))
         
     def message(self, string):
-        print "PokerAvatar: " + string
+        print "PokerAvatar: " + str(string)
         
     def isAuthorized(self, type):
         return self.user.hasPrivilege(self.service.poker_auth.GetLevel(type))
@@ -182,7 +184,8 @@ class PokerAvatar:
     
     def sendPacket(self, packet):
 	if self.explain and not isinstance(packet, defer.Deferred) and packet.type != PACKET_ERROR:
-	    packets = self.explain.explain(packet)
+	    self.explain.explain(packet)
+	    packets = self.explain.forward_packets
 	else:
 	    packets = [ packet ]
         if self._queue_packets:
@@ -382,6 +385,14 @@ class PokerAvatar:
             self.listHands(packet, None)
             return
 
+        elif packet.type == PACKET_POKER_TABLE_JOIN:
+            table = self.service.getTable(packet.game_id)
+            if table:
+                if not table.joinPlayer(self, self.getSerial()):
+                    self.sendPacketVerbose(PacketPokerTable())
+            return
+
+
         table = self.packet2table(packet)
             
         if table:
@@ -564,12 +575,6 @@ class PokerAvatar:
 
             table.update()
 
-        elif packet.type == PACKET_POKER_TABLE_JOIN:
-            table = self.service.getTable(packet.game_id)
-            if table:
-                if not table.joinPlayer(self, self.getSerial()):
-                    self.sendPacketVerbose(PacketPokerTable())
-
         elif not table and packet.type == PACKET_POKER_HAND_REPLAY:
             table = self.createTable(PacketPokerTable())
             if table:
@@ -645,8 +650,9 @@ class PokerAvatar:
                                                     packets = packets))
 
     def listHands(self, packet, serial):
-        start = packet.start
-        count = min(packet.count, 200)
+        if packet.type != PACKET_POKER_HAND_SELECT_ALL:
+            start = packet.start
+            count = min(packet.count, 200)
         if serial != None:
             select_list = "select distinct hands.serial from hands,user2hand "
             select_total = "select count(distinct hands.serial) from hands,user2hand "
@@ -661,11 +667,17 @@ class PokerAvatar:
             if packet.string:
                 where = "where " + packet.string
         where += " order by hands.serial desc"
-        limit = " limit %d,%d " % ( start, count )
+        if packet.type != PACKET_POKER_HAND_SELECT_ALL:
+            limit = " limit %d,%d " % ( start, count )
+        else:
+            limit = '';
         (total, hands) = self.service.listHands(select_list + where + limit, select_total + where)
+        if packet.type == PACKET_POKER_HAND_SELECT_ALL:
+            start = 0
+            count = total
         self.sendPacketVerbose(PacketPokerHandList(string = packet.string,
-                                                   start = packet.start,
-                                                   count = packet.count,
+                                                   start = start,
+                                                   count = count,
                                                    hands = hands,
                                                    total = total))
 
@@ -688,6 +700,11 @@ class PokerAvatar:
         self.tables[game.id] = table
 
         self.sendPacketVerbose(table.toPacket())
+        self.sendPacketVerbose(PacketPokerBuyInLimits(game_id = game.id,
+                                                      min = game.buyIn(),
+                                                      max = game.maxBuyIn(),
+                                                      best = game.bestBuyIn(),
+                                                      rebuy_min = game.minMoney()))
         self.sendPacketVerbose(PacketPokerBatchMode(game_id = game.id))
         nochips = 0
         for player in game.serial2player.values():
