@@ -1,5 +1,5 @@
 #
-# Copyright (C) 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -9,7 +9,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -239,9 +239,11 @@ def makeApplication(argv):
             bot.setServiceParent(services)
     for tournament in settings.headerGetProperties("/settings/tournament"):
         for i in range(0, int(tournament["count"])):
+            bots_count += 1
             tournament['tournament'] = True
             factory = PokerBotFactory(settings = settings,
-                                      join_info = tournament)
+                                      join_info = tournament,
+                                      serial = bots_count)
             bot = Bot(host, port, factory)
             factory.bot = bot
             bot.setServiceParent(services)
