@@ -1,7 +1,8 @@
 #
 # -*- py-indent-offset: 4; coding: iso-8859-1 -*-
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2008 Bradley M. Kuhn <bkuhn@ebb.org>
 # Copyright (C) 2006 Mekensleep
 #
 # Mekensleep
@@ -11,7 +12,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -136,7 +137,8 @@ class PokerCashier:
 
             for ( sql, rowcount ) in sqls:
                 if cursor.execute(sql) < rowcount:
-                    self.error(sql + " affected " + str(cursor.rowcount) + " records instead >= " + str(rowcount))
+                    message = sql + " affected " + str(cursor.rowcount) + " records instead >= " + str(rowcount)
+                    self.error(message)
                     raise PacketError(other_type = PACKET_POKER_CASH_IN,
                                       code = PacketPokerCashIn.SAFE,
                                       message = message)
@@ -191,9 +193,9 @@ class PokerCashier:
         #
         cursor = self.db.cursor()
         try:
-            sql = ( "SELECT transaction_id FROM counter WHERE " +
-                    " currency_serial = " + str(packet.currency_serial) + " AND " +
-                    " serial = " + str(packet.bserial) )
+            sql = ( "SELECT transaction_id FROM counter WHERE " + #pragma: no cover
+                    " currency_serial = " + str(packet.currency_serial) + " AND " + #pragma: no cover
+                    " serial = " + str(packet.bserial) ) #pragma: no cover
             if self.verbose > 2: self.message(sql)
             cursor.execute(sql)
             if cursor.rowcount > 0:
@@ -207,7 +209,8 @@ class PokerCashier:
                 if self.verbose > 2: self.message(sql)
                 cursor.execute(sql)
                 if cursor.rowcount not in (0, 1):
-                    self.error(sql + " found " + str(cursor.rowcount) + " records instead of 0 or 1")
+                    message = sql + " found " + str(cursor.rowcount) + " records instead of 0 or 1"
+                    self.error(message)
                     raise PacketError(other_type = PACKET_POKER_CASH_IN,
                                       code = PacketPokerCashIn.SAFE,
                                       message = message)
@@ -232,11 +235,11 @@ class PokerCashier:
         else:
             transaction = ""
 
-        sql = ( "SELECT counter.user_serial, currencies.url, counter.serial, counter.name, counter.value, counter.application_data FROM counter,currencies " +
-                "       WHERE currencies.serial = " + str(currency_serial) + " AND " +
-                "             counter.currency_serial = " + str(currency_serial) + " AND " +
-                transaction +
-                "             counter.status = 'c' " )
+        sql = ( "SELECT counter.user_serial, currencies.url, counter.serial, counter.name, counter.value, counter.application_data FROM counter,currencies " + #pragma: no cover
+                "       WHERE currencies.serial = " + str(currency_serial) + " AND " + #pragma: no cover
+                "             counter.currency_serial = " + str(currency_serial) + " AND " + #pragma: no cover
+                transaction + #pragma: no cover
+                "             counter.status = 'c' " ) #pragma: no cover
         if self.verbose > 2: self.message(sql)
         cursor.execute(sql)
         if cursor.rowcount == 0:
@@ -278,11 +281,12 @@ class PokerCashier:
                                           message = message)
 
                 packet = self.cashOutCollect(currency_serial, transaction_id)
-                sql = ( "UPDATE user2money SET amount = amount - " + str(packet.value) +
-                        "       WHERE user_serial = " + str(packet.serial) + " AND " +
-                        "             currency_serial = " + str(currency_serial) )
+                sql = ( "UPDATE user2money SET amount = amount - " + str(packet.value) + #pragma: no cover
+                        "       WHERE user_serial = " + str(packet.serial) + " AND " + #pragma: no cover
+                        "             currency_serial = " + str(currency_serial) ) #pragma: no cover
                 if cursor.execute(sql) != 1:
-                    self.error(sql + " affected " + str(cursor.rowcount) + " records instead of 1 ")
+                    message = sql + " affected " + str(cursor.rowcount) + " records instead of 1 "
+                    self.error(message)
                     raise PacketError(other_type = PACKET_POKER_CASH_OUT,
                                       code = PacketPokerCashOut.SAFE,
                                       message = message)
