@@ -1,6 +1,6 @@
 # -*- py-indent-offset: 4; coding: iso-8859-1; mode: python -*-
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -10,7 +10,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -154,7 +154,8 @@ class PokerClientFactory(UGAMEClientFactory):
                 self.delays["blind_ante_position"] = self.delays["position"]
         else:
             self.delays = {}
-        if self.verbose > 2: print "PokerClient: delays %s" % self.delays
+        if self.verbose > 2:
+            self.message("PokerClient: delays %s" % self.delays)
         self.delays_enable = self.settings.headerGet("/settings/@delays") == "true"
         self.skin = PokerSkin(settings = self.settings)
         self.protocol = PokerClientProtocol
@@ -257,7 +258,7 @@ class PokerClientFactory(UGAMEClientFactory):
             if not name:
                 name = config.headerGet("/poker/variant/@name")
                 if not name:
-                    print "*CRITICAL* can't find readable name for %s" % file
+                    self.error("*CRITICAL* can't find readable name for %s" % file)
                     name = file
             self.file2name[file] = name
         return self.file2name[file]
@@ -351,7 +352,7 @@ class PokerClientFactory(UGAMEClientFactory):
 
     def upgradeReady(self, target_dir, upgrades_dir):
         if self.verbose >= 0:
-            print "PokerClientFactory::upgradeReady"
+            self.message("PokerClientFactory::upgradeReady")
         self.children.killall()
         reactor.disconnectAll()
         if hasattr(self.display, "underware"):
@@ -391,12 +392,6 @@ class PokerClientProtocol(UGAMEClientProtocol):
         self._prefix = prefix
         self.explain.setPrefix(prefix)
         
-    def error(self, string):
-        self.message("ERROR " + string)
-        
-    def message(self, string):
-        print self._prefix + string
-        
     def setCurrentGameId(self, game_id):
         if hasattr(self.factory, 'verbose') and self.factory.verbose > 2: self.message("setCurrentGameId(%s)" % game_id)
         self.hold(0)
@@ -459,7 +454,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
             values = []
         list = PokerChips(values, chips).tolist()
         if self.factory.verbose > 4:
-            print "normalizeChips: " + str(list) + " " + str(values)
+            self.message("normalizeChips: " + str(list) + " " + str(values))
         return list
             
     def updatePlayerChips(self, game, player):
@@ -522,7 +517,8 @@ class PokerClientProtocol(UGAMEClientProtocol):
         return packet
         
     def handleUserInfo(self, packet):
-        if self.factory.verbose > 2: print "handleUserInfo: " + str(packet)
+        if self.factory.verbose > 2:
+            self.message("handleUserInfo: " + str(packet))
         self.user_info = packet
 
     def handlePersonalInfo(self, packet):
@@ -550,7 +546,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
             # will return us a PokerPlayerInfo for confirmation of the success.
             #
             if url_check != url or outfit_check != outfit:
-                print "*CRITICAL*: PACKET_POKER_PLAYER_INFO: may enter loop packet.url = %s\n url = %s\n url_check = %s\npacket.outfit = %s\n outfit = %s\n outfit_check = %s" % ( packet.url, url, url_check, packet.outfit, outfit, outfit_check )
+                self.error("*CRITICAL*: PACKET_POKER_PLAYER_INFO: may enter loop packet.url = %s\n url = %s\n url_check = %s\npacket.outfit = %s\n outfit = %s\n outfit_check = %s" % ( packet.url, url, url_check, packet.outfit, outfit, outfit_check ))
             else:
                 packet.url = url
                 packet.outfit = outfit
@@ -562,54 +558,10 @@ class PokerClientProtocol(UGAMEClientProtocol):
         self.sendPacket(PacketLogout())
         self.user.logout()
 
-    def gameEvent(self, game_id, type, *args):
-        if self.factory.verbose > 4:
-            self.message("gameEvent: game_id = %d, type = %s, args = %s" % ( game_id, type, str(args) ))
-
-        forward_packets = self.forward_packets
-        if not forward_packets:
-            if self.factory.verbose > 3:
-                self.message("gameEvent: called outside _handleConnection for game %d, ignored" % game_id)
-            return
-
-        game = self.factory.getGame(game_id)
-        if not game:
-            if self.factory.verbose > 3:
-                self.message("gameEvent: called for unknown game %d, ignored" % game_id)
-            return
-
-        if type == "end_round":
-            forward_packets.append(PacketPokerEndRound(game_id = game_id))
-
-        elif type == "end_round_last":
-            forward_packets.append(PacketPokerEndRoundLast(game_id = game_id))
-
-        elif type == "money2bet":
-            ( serial, amount ) = args
-            player = game.getPlayer(serial)
-            last_action = game.historyGet()[-1][0]
-            if ( last_action == "raise" or last_action == "call" ) :
-                if not self.no_display_packets:
-                    forward_packets.extend(self.updateBetLimit(game))
-                if last_action == "raise":
-                    forward_packets.append(PacketPokerHighestBetIncrease(game_id = game.id))
-            if not self.no_display_packets:
-                forward_packets.extend(self.chipsPlayer2Bet(game, player, amount))
-
-        elif type == "bet2pot":
-            ( serial, amount ) = args
-            if not self.no_display_packets and game.isBlindAnteRound():
-                player = game.getPlayer(serial)
-                forward_packets.extend(self.chipsBet2Pot(game, player, amount, 0))
-
-        elif type == "round_cap_decrease":
-            if not self.no_display_packets:
-                forward_packets.extend(self.updateBetLimit(game))
-
     def setPlayerDelay(self, game, serial, value):
         player = game.getPlayer(serial)
         if player == None:
-            print "WARNING setPlayerDelay for a non-existing player %d" % serial
+            self.message("WARNING setPlayerDelay for a non-existing player %d" % serial)
         else:
             player.getUserData()['delay'] = seconds() + value
 
@@ -713,8 +665,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
                 if packet.game_id != self.getCurrentGameId():
                    self.postMuck(game, True)
 
-        if not self.explain.explain(packet):
-            return
+        self.explain.explain(packet)
 
         if game:
             if packet.type == PACKET_POKER_PLAYER_ARRIVE:
@@ -734,10 +685,10 @@ class PokerClientProtocol(UGAMEClientProtocol):
     
     def connectionLost(self, reason):
         if self.factory.crashing:
-            print "connectionLost: crashing, just return."
+            self.message("connectionLost: crashing, just return.")
             return
         if self.factory.verbose:
-            print "connectionLost: noticed, aborting all tables."
+            self.message("connectionLost: noticed, aborting all tables.")
         self.abortAllTables()
         UGAMEClientProtocol.connectionLost(self, reason)
         
@@ -789,6 +740,11 @@ class PokerClientProtocol(UGAMEClientProtocol):
         packets.append(PacketPokerBatchMode(game_id = game.id))
         packet.seats_all = game.seats_all
         packets.append(packet)
+        packets.append(PacketPokerBuyInLimits(game_id = game.id,
+                                              min = game.buyIn(),
+                                              max = game.maxBuyIn(),
+                                              best = game.bestBuyIn(),
+                                              rebuy_min = game.minMoney()))
         packets.append(PacketPokerDealer(game_id = game.id, dealer = game.dealer_seat))
         for player in game.playersAll():
             packets.append(PacketPokerPlayerArrive(game_id = game.id,
@@ -988,7 +944,7 @@ class PokerClientProtocol(UGAMEClientProtocol):
         packet = self.publish_packets[0]
         if not self.established and not self.factory.isConnectionLess(packet):
             if self.factory.verbose > 5:
-                print "publishPacket: skip because connection not established"
+                self.message("publishPacket: skip because connection not established")
             return
         self.publish_packets.pop(0)
         what = 'outbound'
