@@ -1,10 +1,10 @@
 # -*- py-indent-offset: 4; coding: iso-8859-1; mode: python -*-
 #
-# Copyright (C) 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2007, 2008 Loic Dachary <loic@dachary.org>
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -219,6 +219,10 @@ class PokerExplain:
             if not self.no_display_packets:
                 forward_packets.extend(self.updateBetLimit(game))
 
+        elif type == "position":
+            if game.inGameCount() < 2:
+                forward_packets.append(PacketPokerAllinShowdown(game_id = game.id))
+                
         return True
 
     def handleSerial(self, packet):
@@ -590,6 +594,7 @@ class PokerExplain:
                     if serial_in_position > 0:
                         if position_changed:
                             forward_packets.append(PacketPokerPosition(game_id = game.id,
+                                                                       position = game.position,
                                                                        serial = serial_in_position))
                         if ( self_was_in_position and not self_in_position ):
                             self.unsetPlayerTimeout(game, self.getSerial())
@@ -626,7 +631,7 @@ class PokerExplain:
                                                                message = message))
                 game.history_index = len(game.historyGet())
 
-        return self.forward_packets
+        return True
 
     def serial2name(self, game, serial):
         player = game.getPlayer(serial)
