@@ -1,7 +1,7 @@
 #
 # -*- py-indent-offset: 4; coding: iso-8859-1 -*-
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -11,7 +11,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -38,9 +38,6 @@ import libxml2
 import simplejson
 from traceback import print_exc, format_exc
 
-from MySQLdb.cursors import DictCursor
-from MySQLdb.constants import ER
-
 from OpenSSL import SSL
 
 try:
@@ -57,7 +54,8 @@ from twisted.python.runtime import seconds
 
 try:
     # twisted-2.0
-    from zope.interface import Interface, implements
+    from zope.interface import Interface
+    from zope.interface import implements
 except ImportError:
     # twisted-1.3 forwards compatibility
     def implements(interface):
@@ -75,6 +73,9 @@ except ImportError:
 
     from twisted.python.components import Interface
 
+from MySQLdb.cursors import DictCursor
+from MySQLdb.constants import ER
+
 from twisted.python import components
 
 from pokerengine.pokertournament import *
@@ -187,10 +188,10 @@ class PokerService(service.Service):
         self.down = False
 
     def message(self, string):
-        print "PokerService: " + string
+        print "PokerService: " + str(string)
 
     def error(self, string):
-        self.message("*ERROR* " + string)
+        self.message("*ERROR* " + str(string))
             
     def stopServiceFinish(self, x):
         if self.cashier: self.cashier.close()
@@ -1752,6 +1753,46 @@ def _getRequestCookie(request):
     else:
         return request.getCookie(join(['TWISTED_SESSION'] + request.sitepath, '_'))
 
+#
+# When connecting to the poker server with REST, SOAP or XMLRPC
+# the client must chose to use sessions or not. If using session,
+# the server will issue a cookie and keep track of it during
+# (X == default twisted timeout) minutes.
+#
+# The session cookie is returned as a regular HTTP cookie and
+# the library of the client in charge of the HTTP dialog should
+# handle it transparently. To help the developer using a library
+# that does a poor job at handling the cookies, it is also sent
+# back as the "cookie" field of the PacketSerial packet in response
+# to a successfull authentication request. This cookie may then
+# be used to manually set the cookie header, for instance:
+#
+# Cookie: TWISTED_SESSION=a0bb35083c1ed3bef068d39bd29fad52; Path=/
+#
+# Because this cookie is only sent back in the SERIAL packet following
+# an authentication request, it will not help clients observing the
+# tables. These clients will have to find a way to properly handle the
+# HTTP headers sent by the server.
+#
+# When the client sends a packet to the server using sessions, it must
+# be prepared to receive the backlog of packets accumulated since the
+# last request. For instance,
+#
+#   A client connects in REST session mode
+#   The client sends POKER_TABLE_JOIN and the server replies with
+#   packets describing the state of the table.
+#   A player sitting at the table sends POKER_FOLD.
+#   The server broadcasts the action to all players and observers.
+#   Because the client does not maintain a persistent connection
+#    and is in session mode, the server keeps the POKER_FOLD packet
+#    for later.
+#   The client sends PING to tell the server that it is still alive.
+#   In response the server sends it the cached POKER_FOLD packet and
+#    the client is informed of the action.
+#
+# The tests/test-webservice.py.in tests contain code that will help
+# understand the usage of the REST, SOAP and XMLRPC protocols.
+#
 class PokerXML(resource.Resource):
 
     encoding = "ISO-8859-1"
@@ -1830,7 +1871,7 @@ class PokerXML(resource.Resource):
             def renderLater(packet):
                 result_maps = self.packets2maps([packet])
 
-                result_string = self.maps2result(result_maps)
+                result_string = self.maps2result(request, result_maps)
                 request.setHeader("Content-length", str(len(result_string)))
                 request.write(result_string)
                 request.finish()
@@ -1841,14 +1882,17 @@ class PokerXML(resource.Resource):
         else:
             if use_sessions != "use sessions":
                 self.service.destroyAvatar(avatar)
-            elif use_sessions == "use sessions" and logout:
-                session.expire()
+            elif use_sessions == "use sessions":
+                if logout:
+                    session.expire()
+                else:
+                    avatar.queuePackets()
 
             result_maps = self.packets2maps(result_packets)
 
-            result_string = self.maps2result(result_maps)
+            result_string = self.maps2result(request, result_maps)
             if self.verbose > 2:
-                self.message("result_string xml " + str(result_string))
+                self.message("result_string " + str(result_string))
             request.setHeader("Content-length", str(len(result_string)))
             return result_string
 
@@ -1869,6 +1913,8 @@ class PokerXML(resource.Resource):
         maps = []
         for packet in packets:
             attributes = packet.__dict__.copy()
+            if isinstance(packet, PacketList):
+                attributes['packets'] = self.packets2maps(attributes['packets'])
             if 'message' in dir(packet):
                 attributes['message'] = getattr(packet, 'message')
             #
@@ -1893,7 +1939,7 @@ class PokerXML(resource.Resource):
     def getArguments(self, request):
         pass
 
-    def maps2result(self, maps):
+    def maps2result(self, request, maps):
         pass
 
     @staticmethod
@@ -1931,24 +1977,60 @@ class PokerXMLRPC(PokerXML):
         ( args, functionPath ) = xmlrpclib.loads(request.content.read())
         return PokerXML.fromutf8(args, self.encoding)
 
-    def maps2result(self, maps):
+    def maps2result(self, request, maps):
         return xmlrpclib.dumps((maps, ), methodresponse = 1)
 
 class PokerREST(PokerXML):
 
     def getArguments(self, request):
-        if request.args.get('session', ['no'])[0] == 'yes':
-            session = 'use sessions'
+        use_sessions = request.args.get('session', ['no'])[0]
+        session_name = request.args.get('name', [None])[0]
+        if session_name:
+            request.sitepath = [ session_name ]
         else:
-            session = 'no sessions'
+            request.sitepath = [ ]
 
-        args = simplejson.loads(request.content.read(), encoding = 'latin-1')
+        if use_sessions == 'no':
+            use_sessions = 'no sessions'
+        elif use_sessions in ( 'clear', 'new' ):
+            #
+            # Force session expiration.
+            # 
+            # NOTE 1: that request.getSession() will create a session
+            # if no session exists. However, since it is a light
+            # weight operation that will be canceled by
+            # session.expire(), it is ok.
+            #
+            # NOTE 2: the avatar attached to the session will be destroyed
+            # as a side effect, because a callback was attached to the
+            # session expiration.
+            #
+            request.getSession().expire()
+            request.session = None
+            request.cookies = []
+            if use_sessions == 'clear':
+                use_sessions = 'no sessions'
+            elif use_sessions == 'new':
+                use_sessions = 'use sessions'
+        elif use_sessions == 'yes':
+            use_sessions = 'use sessions'
+
+        jsonp = request.args.get('jsonp', [''])[0]
+        if jsonp:
+            data = request.args.get('packet', [''])[0]
+        else:
+            data = request.content.read()
+        args = simplejson.loads(data, encoding = 'latin-1')
         if hasattr(Packet.JSON, 'decode_objects'):
             args = Packet.JSON.decode_objects(args)
-        return [ session, PokerXML.fromutf8(args, self.encoding) ]
+        return [ use_sessions, PokerXML.fromutf8(args, self.encoding) ]
 
-    def maps2result(self, maps):
-        return Packet.JSON.encode(maps)
+    def maps2result(self, request, maps):
+        jsonp = request.args.get('jsonp', [''])[0]
+        if jsonp:
+            return jsonp + '(' + str(Packet.JSON.encode(maps)) + ')'
+        else:
+            return str(Packet.JSON.encode(maps))
 
 try:
     import SOAPpy
@@ -1970,7 +2052,7 @@ try:
 
             return PokerXML.fromutf8(SOAPpy.simplify(args), self.encoding)
 
-        def maps2result(self, maps):
+        def maps2result(self, request, maps):
             return SOAPpy.buildSOAP(kw = {'Result': PokerXML.toutf8(maps, self.encoding)},
                                     method = 'returnPacket',
                                     encoding = self.encoding)
