@@ -1,7 +1,7 @@
 #
 # -*- coding: iso-8859-1 -*-
 #
-# Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+# Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -11,7 +11,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -115,6 +115,13 @@ class PokerTable:
         self.broadcast(PacketPokerTableDestroy(game_id = self.game.id))
         for client in self.serial2client.values() + self.observers:
             del client.tables[self.game.id]
+            # FIXME: I don't think that PokerTable should be reaching into
+            #        the member variables of the client classes.  Really
+            #        the line above should be something like
+            #        client.removeTable(self.game.id).  I did not change
+            #        based on IRC discussions with Loic, but I have
+            #        written tests in ../tests/test-pokertable.py.in that
+            #        should check after this change is made.
             
         self.factory.deleteTable(self)
         del self.factory
@@ -1086,9 +1093,11 @@ class PokerTable:
     def joinPlayer(self, client, serial):
         game = self.game
         #
-        # Silently do nothing if already joined
+        # Nothing to be done except sending all packets
+        # Useful in disconnected mode to resume a session.
         #
         if self.isJoined(client):
+            client.join(self);
             return True
 
         if len(client.tables) >= self.factory.simultaneous:
@@ -1208,6 +1217,13 @@ class PokerTable:
         else:
             del self.serial2client[serial]
         del client.tables[self.game.id]
+        # FIXME: I don't think that PokerTable should be reaching into the
+        #        member variables of the client classes.  Really the line
+        #        above should be something like
+        #        client.removeTable(self.game.id).  I did not change based
+        #        on IRC discussions with Loic, but I have written tests in
+        #        ../tests/test-pokertable.py.in that should check after
+        #        this change is made.
 
     def buyInPlayer(self, client, amount):
         game = self.game
