@@ -1,4 +1,5 @@
 #
+# Copyright (C) 2008 Loic Dachary <loic@dachary.org>
 # Copyright (C) 2004, 2005, 2006 Mekensleep
 #
 # Mekensleep
@@ -8,7 +9,7 @@
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
-# the Free Software Foundation; either version 2 of the License, or
+# the Free Software Foundation; either version 3 of the License, or
 # (at your option) any later version.
 #
 # This program is distributed in the hope that it will be useful,
@@ -151,6 +152,12 @@ class PokerInteractor:
         self.changed = True
         self.update()        
 
+    def error(self, string):
+        self.message("ERROR " + string)
+        
+    def message(self, string):
+        print string
+        
     def setUserData(self, userData):
         if self.userData != userData:
             self.userData = userData
@@ -261,9 +268,11 @@ class PokerInteractor:
         
     def update(self):        
         if self.changed:
-            if self.verbose > 3: print self.prefix + " PokerInteractor::update: before " + self.name + ": state " + self.state.name + ", canceled " + str(self.canceled) + ", selected " + str(self.selected) + ", inPosition " + str(self.inPosition) + ", userData " + str(self.userData)
+            if self.verbose > 3:
+                self.message(self.prefix + " PokerInteractor::update: before " + self.name + ": state " + self.state.name + ", canceled " + str(self.canceled) + ", selected " + str(self.selected) + ", inPosition " + str(self.inPosition) + ", userData " + str(self.userData))
             self.state.update(self)
-            if self.verbose > 3: print self.prefix + "                         after  " + self.name + ": state " + self.state.name + ", canceled " + str(self.canceled) + ", selected " + str(self.selected) + ", inPosition " + str(self.inPosition) + ", userData " + str(self.userData)
+            if self.verbose > 3:
+                self.message(self.prefix + "                         after  " + self.name + ": state " + self.state.name + ", canceled " + str(self.canceled) + ", selected " + str(self.selected) + ", inPosition " + str(self.inPosition) + ", userData " + str(self.userData))
             self.displayCallback(self)
             self.changed = False
             self.state.changed = False
