@@ -1,6 +1,6 @@
 <?php
 //
-// Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+// Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 // Copyright (C) 2006 Mekensleep
 //
 // Mekensleep
@@ -10,7 +10,7 @@
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -83,6 +83,8 @@ if(_post_string('submit')) {
   } catch(Exception $error) {
     $poker_error = $error->getMessage();
   }
+} else {
+  $currency = 1;
 }
 
 hci_header();
