@@ -1,6 +1,6 @@
 <?php
 //
-// Copyright (C) 2006, 2007 Loic Dachary <loic@dachary.org>
+// Copyright (C) 2006, 2007, 2008 Loic Dachary <loic@dachary.org>
 // Copyright (C) 2006 Mekensleep
 //
 // Mekensleep
@@ -10,7 +10,7 @@
 //
 // This program is free software; you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
-// the Free Software Foundation; either version 2 of the License, or
+// the Free Software Foundation; either version 3 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
@@ -115,8 +115,8 @@ class currency {
     }
 
     $this->db_persist = $GLOBALS['currency_db_persist'];
-    $this->db_host = "localhost";
-    $this->db_port = 3306;
+    $this->db_host = $GLOBALS['currency_db_host'];
+    $this->db_port = $GLOBALS['currency_db_port'];
     $this->db_base = $base;
     $this->db_user = $user;
     $this->db_password = $password;
